/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { NextResponse } from "next/server";
import { getCodebergActivty } from "../../../lib/codeberg";
import { getGithubData } from "../../../lib/github";

/**
 * GET route handler for the activity API.
 * Loads recent activity from Codeberg and GitHub.
 * @returns The formatted data.
 */
export async function GET(): Promise<NextResponse> {
  const codeberg = await getCodebergActivty();
  const github = await getGithubData();

  const normalised: Array<{
    type:     string;
    date:     Date;
    repo:     string;
    repoName: string;
  }> = [
    ...codeberg.map((index) => {
      return {
        date:     new Date(index.created),
        repo:     index.repo.html_url,
        repoName: index.repo.full_name,
        type:     index.op_type,
      };
    }),
    ...github.map((index) => {
      return {
        date:     new Date(index.created_at),
        repo:     index.repo.url.replace("api.github.com/repos", "github.com"),
        repoName: index.repo.name,
        type:     index.type,
      };
    }),
  ];

  return NextResponse.json(
    normalised.
      toSorted((a, b) => {
        return new Date(b.date).getTime() - new Date(a.date).getTime();
      }).
      slice(0, 100),
  );
}
